pub struct LayoutObject(/* private fields */);Expand description
Type erased Layout.
Implementations
Sourceimpl LayoutObject
impl LayoutObject
Sourcepub const PADDING: LayoutObject
pub const PADDING: LayoutObject
Dynamic sized layout that conforms to child size and adds Container::padding to it.
Sourcepub const HSTACK: LayoutObject
pub const HSTACK: LayoutObject
A dynamic sized horizontal layout.
Sourcepub const VSTACK: LayoutObject
pub const VSTACK: LayoutObject
A dynamic sized vertical layout.
Sourcepub const HBOX: LayoutObject
pub const HBOX: LayoutObject
A fix sized horizontal layout.
Sourcepub const VBOX: LayoutObject
pub const VBOX: LayoutObject
A fix sized vertical layout.
Sourcepub const PARAGRAPH: LayoutObject
pub const PARAGRAPH: LayoutObject
A horizontal layout with line breaks.
pub fn new(layout: impl Layout) -> Self
pub fn downcast_ref<T: Layout>(&self) -> Option<&T>
pub fn downcast_mut<T: Layout>(&mut self) -> Option<&mut T>
Methods from Deref<Target = dyn Layout>
Sourcepub fn is<__T: Layout>(&self) -> bool
pub fn is<__T: Layout>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast_rc<__T: Layout>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: Layout>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: Layout>(&self) -> Option<&__T>
pub fn downcast_ref<__T: Layout>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.